@@ -51,107 +51,14 @@
 
 #include "xutils.h"
 
+#include "error_strings.h"
+
 
 /**
  *
  */
 WnckWindow *current_window=NULL;
 
-gchar *no_indata_expected_error=NULL;
-gchar *one_indata_expected_error=NULL;
-gchar *two_indata_expected_error=NULL;
-gchar *four_indata_expected_error=NULL;
-
-gchar *number_expected_as_indata_error=NULL;
-gchar *boolean_expected_as_indata_error=NULL;
-
-gchar *string_expected_as_indata_error=NULL;
-
-gchar *failed_string=NULL;
-
-/**
- *
- */
-int init_script_error_messages()
-{
-#define ALLOCATE_ERROR_STRING _("Couldn't allocate error string!")
-
-	no_indata_expected_error=g_strdup_printf(_("No indata expected"));
-	if (!no_indata_expected_error) {
-		printf(ALLOCATE_ERROR_STRING);
-		printf("\n");
-		return -1;
-	}
-
-	one_indata_expected_error=g_strdup_printf(_("One indata expected"));
-	if (!one_indata_expected_error) {
-		printf(ALLOCATE_ERROR_STRING);
-		printf("\n");
-		return -1;
-	}
-
-	two_indata_expected_error=g_strdup_printf(_("Two indata expected"));
-	if (!two_indata_expected_error) {
-		printf(ALLOCATE_ERROR_STRING);
-		printf("\n");
-		return -1;
-	}
-
-	four_indata_expected_error=g_strdup_printf(_("Four indata expected"));
-	if (!four_indata_expected_error) {
-		printf(ALLOCATE_ERROR_STRING);
-		printf("\n");
-		return -1;
-	}
-
-	number_expected_as_indata_error=g_strdup_printf(_("Number expected as indata"));
-	if (!number_expected_as_indata_error) {
-		printf(ALLOCATE_ERROR_STRING);
-		printf("\n");
-		return -1;
-	}
-
-	boolean_expected_as_indata_error=g_strdup_printf(_("Boolean expected as indata"));
-	if (!boolean_expected_as_indata_error) {
-		printf(ALLOCATE_ERROR_STRING);
-		printf("\n");
-		return -1;
-	}
-
-	string_expected_as_indata_error=g_strdup_printf(_("String expected as indata"));
-	if (!string_expected_as_indata_error) {
-		printf(ALLOCATE_ERROR_STRING);
-		printf("\n");
-		return -1;
-	}
-
-	failed_string=g_strdup_printf(_("Failed!"));
-	if (!failed_string) {
-		printf(ALLOCATE_ERROR_STRING);
-		printf("\n");
-		return -1;
-	}
-
-	return 0;
-}
-
-
-/**
- *
- */
-void done_script_error_messages()
-{
-	g_free(no_indata_expected_error);
-	g_free(one_indata_expected_error);
-	g_free(two_indata_expected_error);
-	g_free(four_indata_expected_error);
-
-	g_free(number_expected_as_indata_error);
-	g_free(boolean_expected_as_indata_error);
-	g_free(string_expected_as_indata_error);
-
-	g_free(failed_string);
-}
 
 
 /**
@@ -1517,3 +1424,62 @@ int c_set_window_fullscreen(lua_State *lua)
 
 	return 0;
 }
+
+
+/**
+ *
+ */
+int c_set_viewport(lua_State *lua)
+{
+	int top=lua_gettop(lua);
+	WnckScreen *screen;
+	int x,y,width,height, viewport_start;
+
+	if (top!=1) {
+		luaL_error(lua,"set_viewport: %s", one_indata_expected_error);
+		return 0;
+	}
+
+	int type=lua_type(lua,1);
+	if (type!=LUA_TNUMBER) {
+		luaL_error(lua,"set_viewport: %s",number_expected_as_indata_error);
+		return 0;
+	}
+
+	int num=lua_tonumber(lua,1);
+
+	if (num<=0) {
+		g_error("set_viewport: %s",integer_greater_than_zero_expected_error);
+		lua_pushboolean(lua,FALSE);
+		return 1;
+	}
+
+	WnckWindow *window=get_current_window();
+
+	screen=wnck_window_get_screen(window);
+
+	wnck_window_get_geometry(window, &x, &y, &width, &height);
+
+	viewport_start=my_wnck_get_viewport_start(window);
+	if (viewport_start<0) {
+		g_printerr("set_viewport: %s",could_not_find_current_viewport_error);
+		lua_pushboolean(lua,FALSE);
+		return 1;
+	}
+
+	x=((num-1) * wnck_screen_get_width(screen)) - viewport_start + x;
+
+	my_wnck_error_trap_push();
+	XMoveResizeWindow(gdk_x11_get_default_xdisplay(),
+	                  wnck_window_get_xid(window),
+	                  x,y,width,height);
+
+	if (my_wnck_error_trap_pop()) {
+		g_printerr("set_viewport: %s",setting_viewport_failed_error);
+		lua_pushboolean(lua,FALSE);
+		return 1;
+	}
+
+	lua_pushboolean(lua,TRUE);
+	return 1;
+}
