@@ -23,9 +23,6 @@
 /**
  *
  */
-int init_script_error_messages();
-void done_script_error_messages();
-
 int c_get_window_name(lua_State *lua);
 int c_get_window_has_name(lua_State *lua);
 
@@ -98,4 +95,6 @@ int c_get_window_xid(lua_State *lua);
 
 int c_get_window_class(lua_State *lua);
 
+int c_set_viewport(lua_State *lua);
+
 #endif /*__HEADER_SCRIPT_FUNCTIONS_*/
